Module: kamailio
Branch: 5.5
Commit: 548e14cb12a9d39374ee20c9e5ab35b84c609a0c
URL:
https://github.com/kamailio/kamailio/commit/548e14cb12a9d39374ee20c9e5ab35b…
Author: Henning Westerholt <hw(a)skalatan.de>
Committer: Henning Westerholt <hw(a)skalatan.de>
Date: 2021-09-28T11:30:29Z
topos: reset vavu variable, otherwise we will get errors in contact_mode 2 (GH #2852)
(cherry picked from commit 5484b7a2bf662d3bced662d11a04e1f25f965023)
---
Modified: src/modules/topos/tps_storage.c
---
Diff:
https://github.com/kamailio/kamailio/commit/548e14cb12a9d39374ee20c9e5ab35b…
Patch:
https://github.com/kamailio/kamailio/commit/548e14cb12a9d39374ee20c9e5ab35b…
---
diff --git a/src/modules/topos/tps_storage.c b/src/modules/topos/tps_storage.c
index b94a960340..1a67c0252c 100644
--- a/src/modules/topos/tps_storage.c
+++ b/src/modules/topos/tps_storage.c
@@ -352,7 +352,8 @@ int tps_storage_fill_contact(sip_msg_t *msg, tps_data_t *td, str
*uuid, int dir,
td->cp++;
}
- /* contact_host xavu takes preference */
+ /* contact_host xavu takes preference, reset vavu */
+ vavu = NULL;
if (_tps_xavu_cfg.len>0 && _tps_xavu_field_contact_host.len>0) {
vavu = xavu_get_child_with_sval(&_tps_xavu_cfg,
&_tps_xavu_field_contact_host);